@@ -25,9 +25,12 @@
 #include "HeadlessProcessor.h"
 #include <QDebug>
 #include <QSettings>
+#include <QStringList>
 #include "Common.h"
+#include "FilterParameters/FilterParametersWidget.h"
 #include "FilterThread.h"
 #include "GmicStdlib.h"
+#include "ParametersCache.h"
 #include "Updater.h"
 #include "gmic.h"
 
@@ -37,8 +40,15 @@
 #include <psapi.h>
 #endif
 
+/**
+ * @brief HeadlessProcessor::HeadlessProcessor
+ * @param parent
+ * @param command
+ * @param inputMode
+ * @param outputMode
+ */
 HeadlessProcessor::HeadlessProcessor(QObject * parent, const char * command, GmicQt::InputMode inputMode, GmicQt::OutputMode outputMode)
-    : QObject(parent), _filterThread(0), _gmicImages(new cimg_library::CImgList<gmic_pixel_type>)
+    : QObject(parent), _filterThread(nullptr), _gmicImages(new cimg_library::CImgList<gmic_pixel_type>)
 {
   _filterName = "Custom command";
   _lastCommand = "skip 0";
@@ -51,15 +61,28 @@ HeadlessProcessor::HeadlessProcessor(QObject * parent, const char * command, Gmi
   _timer.setInterval(250);
   connect(&_timer, SIGNAL(timeout()), this, SLOT(onTimeout()));
   _hasProgressWindow = false;
+  ParametersCache::load(true);
+  _processingCompletedProperly = false;
 }
 
-HeadlessProcessor::HeadlessProcessor(QObject * parent) : QObject(parent), _filterThread(0), _gmicImages(new cimg_library::CImgList<gmic_pixel_type>)
+/**
+ * @brief HeadlessProcessor::HeadlessProcessor using "last parameters" from config file
+ * @param parent
+ */
+HeadlessProcessor::HeadlessProcessor(QObject * parent) : QObject(parent), _filterThread(nullptr), _gmicImages(new cimg_library::CImgList<gmic_pixel_type>)
 {
   QSettings settings;
   _filterName = settings.value(QString("LastExecution/host_%1/FilterName").arg(GmicQt::HostApplicationShortname)).toString();
   _lastCommand = settings.value(QString("LastExecution/host_%1/Command").arg(GmicQt::HostApplicationShortname)).toString();
   _lastArguments = settings.value(QString("LastExecution/host_%1/Arguments").arg(GmicQt::HostApplicationShortname)).toString();
-  _outputMessageMode = (GmicQt::OutputMessageMode)settings.value(QString("OutputMessageMode").arg(GmicQt::HostApplicationShortname), GmicQt::Quiet).toInt();
+
+  QStringList lastAppliedCommandGmicStatus = settings.value(QString("LastExecution/host_%1/GmicStatus").arg(GmicQt::HostApplicationShortname)).toStringList();
+  _gmicStatusQuotedParameters = settings.value(QString("LastExecution/host_%1/QuotedParameters").arg(GmicQt::HostApplicationShortname)).toString();
+  if (!lastAppliedCommandGmicStatus.isEmpty()) {
+    _lastArguments = FilterParametersWidget::flattenParameterList(lastAppliedCommandGmicStatus, _gmicStatusQuotedParameters);
+  }
+
+  _outputMessageMode = (GmicQt::OutputMessageMode)settings.value("OutputMessageMode", GmicQt::DefaultOutputMessageMode).toInt();
   _inputMode = (GmicQt::InputMode)settings.value(QString("LastExecution/host_%1/InputMode").arg(GmicQt::HostApplicationShortname), GmicQt::InputMode::Active).toInt();
   _outputMode = (GmicQt::OutputMode)settings.value(QString("LastExecution/host_%1/OutputMode").arg(GmicQt::HostApplicationShortname), GmicQt::OutputMode::InPlace).toInt();
   _lastEnvironment = settings.value(QString("LastExecution/host_%1/GmicEnvironment").arg(GmicQt::HostApplicationShortname), QString()).toString();
@@ -69,6 +92,7 @@ HeadlessProcessor::HeadlessProcessor(QObject * parent) : QObject(parent), _filte
   _singleShotTimer.setSingleShot(true);
   connect(&_singleShotTimer, SIGNAL(timeout()), this, SIGNAL(singleShotTimeout()));
   _hasProgressWindow = false;
+  ParametersCache::load(true);
 }
 
 HeadlessProcessor::~HeadlessProcessor()
@@ -90,7 +114,7 @@ void HeadlessProcessor::startProcessing()
   _filterThread = new FilterThread(this, _filterName, _lastCommand, _lastArguments, _lastEnvironment, _outputMessageMode);
   _filterThread->swapImages(*_gmicImages);
   _filterThread->setImageNames(imageNames);
-
+  _processingCompletedProperly = false;
   connect(_filterThread, SIGNAL(finished()), this, SLOT(onProcessingFinished()));
   _timer.start();
   _filterThread->start();
@@ -111,6 +135,11 @@ void HeadlessProcessor::setProgressWindowFlag(bool value)
   _hasProgressWindow = value;
 }
 
+bool HeadlessProcessor::processingCompletedProperly()
+{
+  return _processingCompletedProperly;
+}
+
 void HeadlessProcessor::onTimeout()
 {
   if (!_filterThread) {
@@ -142,31 +171,35 @@ void HeadlessProcessor::onTimeout()
 
 void HeadlessProcessor::onProcessingFinished()
 {
-  QString errorMessage;
   _timer.stop();
-  QStringList list = _filterThread->gmicStatus();
-  if (!list.isEmpty()) {
+  QString errorMessage;
+  QStringList status = _filterThread->gmicStatus();
+  if (!status.isEmpty()) {
     QSettings settings;
-    QString params = list.join(",");
-    settings.setValue(QString("LastExecution/host_%1/Arguments").arg(GmicQt::HostApplicationShortname), params);
+    settings.setValue(QString("LastExecution/host_%1/GmicStatus").arg(GmicQt::HostApplicationShortname), status);
+    QString lastArguments = FilterParametersWidget::flattenParameterList(status, _gmicStatusQuotedParameters);
+    settings.setValue(QString("LastExecution/host_%1/Arguments").arg(GmicQt::HostApplicationShortname), lastArguments);
+    QString hash = settings.value(QString("LastExecution/host_%1/FilterHash").arg(GmicQt::HostApplicationShortname)).toString();
+    ParametersCache::setValues(hash, status);
+    ParametersCache::save();
   }
   if (_filterThread->failed()) {
     errorMessage = _filterThread->errorMessage();
   } else {
     gmic_list<gmic_pixel_type> images = _filterThread->images();
     if (!_filterThread->aborted()) {
-      gmic_qt_output_images(images, _filterThread->imageNames(), _outputMode,
-                            (_outputMessageMode == GmicQt::VerboseLayerName) ? QString("[G'MIC] %1: %2").arg(_filterThread->name()).arg(_filterThread->fullCommand()).toLocal8Bit().constData() : 0);
+      gmic_qt_output_images(images, _filterThread->imageNames(), _outputMode);
+      _processingCompletedProperly = true;
     }
   }
   _filterThread->deleteLater();
-  _filterThread = 0;
+  _filterThread = nullptr;
   _singleShotTimer.stop();
   emit done(errorMessage);
   if (!_hasProgressWindow && !errorMessage.isEmpty()) {
     qWarning() << "Error:" << errorMessage;
   }
-  qApp->exit(0);
+  QCoreApplication::exit(0);
 }
 
 void HeadlessProcessor::cancel()
