@@ -31,6 +31,9 @@
 #include <limits>
 #include <stack>
 #include <vector>
+#ifdef _IS_WINDOWS_
+#include <QTextCodec>
+#endif
 #include "Common.h"
 #include "Host/host.h"
 #include "ImageTools.h"
@@ -42,6 +45,8 @@
  * of the GTK version of the gmic plug-in for GIMP by David Tschumperl\'e.
  */
 
+#define GIMP_VERSION_LTE(MAJOR, MINOR) (GIMP_MAJOR_VERSION < MAJOR) || ((GIMP_MAJOR_VERSION == MAJOR) && (GIMP_MINOR_VERSION <= MINOR))
+
 #define _gimp_image_get_item_position gimp_image_get_item_position
 
 #if (GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 7) && (GIMP_MICRO_VERSION <= 14)
@@ -54,7 +59,7 @@ namespace GmicQt
 {
 const QString HostApplicationName = QString("GIMP %1.%2").arg(GIMP_MAJOR_VERSION).arg(GIMP_MINOR_VERSION);
 const char * HostApplicationShortname = GMIC_QT_XSTRINGIFY(GMIC_HOST);
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
 const bool DarkThemeIsDefault = false;
 #else
 const bool DarkThemeIsDefault = true;
@@ -159,6 +164,23 @@ QString blendingMode2String(const GimpLayerModeEffects & blendingMode)
   }
 }
 
+#ifdef _IS_WINDOWS_
+QByteArray mapToASCII(const char * str)
+{
+  static const QTextCodec * codec = QTextCodec::codecForName("ASCII");
+  return codec->fromUnicode(QString::fromUtf8(str));
+}
+inline void _GIMP_ITEM_SET_NAME(gint32 item_ID, const gchar * name)
+{
+  gimp_item_set_name(item_ID, mapToASCII(name).constData());
+}
+#else
+inline void _GIMP_ITEM_SET_NAME(gint32 item_ID, const gchar * name)
+{
+  gimp_item_set_name(item_ID, name);
+}
+#endif
+
 // Get layer blending mode from string.
 //-------------------------------------
 void get_output_layer_props(const char * const s, GimpLayerModeEffects & blendmode, double & opacity, int & posx, int & posy, cimg_library::CImg<char> & name)
@@ -279,7 +301,7 @@ void gmic_qt_show_message(const char * message)
 
 void gmic_qt_apply_color_profile(cimg_library::CImg<float> & image)
 {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
   unused(image);
 // SWAP RED<->GREEN CHANNELS : FOR TESTING PURPOSE ONLY!
 //  cimg_forXY(image,x,y) {
@@ -521,7 +543,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
     QString name = QString("mode(%1),opacity(%2),pos(%3,%4),name(%5)").arg(blendingMode2String(blendMode)).arg(opacity).arg(xPos).arg(yPos).arg(noParenthesisName);
     QByteArray ba = name.toUtf8();
     gmic_image<char>::string(ba.constData()).move_to(imageNames[l]);
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
     GimpDrawable * drawable = gimp_drawable_get(inputLayers[l]);
     GimpPixelRgn region;
     gimp_pixel_rgn_init(&region, drawable, ix, iy, iw, ih, false, false);
@@ -543,7 +565,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
   }
 }
 
-void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<char> & imageNames, GmicQt::OutputMode outputMode, const char * verboseLayersLabel)
+void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<char> & imageNames, GmicQt::OutputMode outputMode)
 {
   // Output modes in original gmic_gimp_gtk : 0/Replace 1/New layer 2/New active layer  3/New image
 
@@ -616,14 +638,10 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
         gimp_drawable_offsets(inputLayers[p], &layer_posx, &layer_posy);
         cimg_library::CImg<char>::string(gimp_item_get_name(inputLayers[p])).move_to(layer_name);
         get_output_layer_props(imageNames[p], layer_blendmode, layer_opacity, layer_posx, layer_posy, layer_name);
-        if (is_selection) {
-          layer_posx = 0;
-          layer_posy = 0;
-        }
         cimg_library::CImg<gmic_pixel_type> & img = images[p];
         GmicQt::calibrate_image(img, inputLayerDimensions(p, 3), false);
         if (gimp_drawable_mask_intersect(inputLayers[p], &rgn_x, &rgn_y, &rgn_width, &rgn_height)) {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(inputLayers[p]);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, rgn_x, rgn_y, rgn_width, rgn_height, true, true);
@@ -646,12 +664,17 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
 #endif
           gimp_layer_set_mode(inputLayers[p], layer_blendmode);
           gimp_layer_set_opacity(inputLayers[p], layer_opacity);
-          gimp_layer_set_offsets(inputLayers[p], layer_posx, layer_posy);
-
-          if (verboseLayersLabel) { // Verbose (layer name)
-            gimp_item_set_name(inputLayers[p], verboseLayersLabel);
-          } else if (layer_name) {
-            gimp_item_set_name(inputLayers[p], layer_name);
+          if (!is_selection) {
+            gimp_layer_set_offsets(inputLayers[p], layer_posx, layer_posy);
+          } else {
+#if GIMP_VERSION_LTE(2, 8)
+            gimp_layer_translate(inputLayers[p], 0, 0);
+#else
+            gimp_item_transform_translate(inputLayers[p], 0, 0);
+#endif
+          }
+          if (layer_name) {
+            _GIMP_ITEM_SET_NAME(inputLayers[p], layer_name);
           }
         }
         img.assign();
@@ -692,16 +715,14 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           } else {
             GmicQt::calibrate_image(img, (img.spectrum() == 1 || img.spectrum() == 3) ? 3 : 4, false);
           }
-          gint layer_id = gimp_layer_new(gmic_qt_gimp_image_id, verboseLayersLabel, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
+          gint layer_id = gimp_layer_new(gmic_qt_gimp_image_id, nullptr, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
           gimp_layer_set_offsets(layer_id, layer_posx, layer_posy);
-          if (verboseLayersLabel) {
-            gimp_item_set_name(layer_id, verboseLayersLabel);
-          } else if (layer_name) {
-            gimp_item_set_name(layer_id, layer_name);
+          if (layer_name) {
+            _GIMP_ITEM_SET_NAME(layer_id, layer_name);
           }
           gimp_image_insert_layer(gmic_qt_gimp_image_id, layer_id, -1, layer_pos + p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
@@ -767,19 +788,17 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           } else {
             GmicQt::calibrate_image(img, !is_selection && (img.spectrum() == 1 || img.spectrum() == 3) ? 3 : 4, false);
           }
-          layer_id = gimp_layer_new(gmic_qt_gimp_image_id, verboseLayersLabel, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
+          layer_id = gimp_layer_new(gmic_qt_gimp_image_id, nullptr, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
           if (!p) {
             top_layer_id = layer_id;
           }
           gimp_layer_set_offsets(layer_id, layer_posx, layer_posy);
-          if (verboseLayersLabel) {
-            gimp_item_set_name(layer_id, verboseLayersLabel);
-          } else if (layer_name) {
-            gimp_item_set_name(layer_id, layer_name);
+          if (layer_name) {
+            _GIMP_ITEM_SET_NAME(layer_id, layer_name);
           }
           gimp_image_insert_layer(gmic_qt_gimp_image_id, layer_id, -1, p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
@@ -820,7 +839,7 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
     const unsigned int max_width = (unsigned int)bottom_right.x;
     const unsigned int max_height = (unsigned int)bottom_right.y;
     if (active_layer_id >= 0) {
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
       const int nimage_id = gimp_image_new(max_width, max_height, max_spectrum <= 2 ? GIMP_GRAY : GIMP_RGB);
 #else
       const int nimage_id = gimp_image_new_with_precision(max_width, max_height, max_spectrum <= 2 ? GIMP_GRAY : GIMP_RGB, gimp_image_get_precision(gmic_qt_gimp_image_id));
@@ -848,16 +867,14 @@ void gmic_qt_output_images(gmic_list<gmic_pixel_type> & images, const gmic_list<
           if (gimp_image_base_type(nimage_id) != GIMP_GRAY) {
             GmicQt::calibrate_image(img, (img.spectrum() == 1 || img.spectrum() == 3) ? 3 : 4, false);
           }
-          gint layer_id = gimp_layer_new(nimage_id, verboseLayersLabel, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
+          gint layer_id = gimp_layer_new(nimage_id, nullptr, img.width(), img.height(), spectrum2gimpImageTypes[std::min(img.spectrum(), 4)], layer_opacity, layer_blendmode);
           gimp_layer_set_offsets(layer_id, layer_posx, layer_posy);
-          if (verboseLayersLabel) {
-            gimp_item_set_name(layer_id, verboseLayersLabel);
-          } else if (layer_name) {
-            gimp_item_set_name(layer_id, layer_name);
+          if (layer_name) {
+            _GIMP_ITEM_SET_NAME(layer_id, layer_name);
           }
           gimp_image_insert_layer(nimage_id, layer_id, -1, p);
 
-#if (GIMP_MAJOR_VERSION < 2) || ((GIMP_MAJOR_VERSION == 2) && (GIMP_MINOR_VERSION <= 8))
+#if GIMP_VERSION_LTE(2, 8)
           GimpDrawable * drawable = gimp_drawable_get(layer_id);
           GimpPixelRgn region;
           gimp_pixel_rgn_init(&region, drawable, 0, 0, drawable->width, drawable->height, true, true);
