@@ -267,7 +267,7 @@ void gmic_qt_get_layers_extent(int * width, int * height, GmicQt::InputMode mode
 
     if (reply.length() > 0)
     {
-        QStringList items = reply.split(',', QString::SkipEmptyParts);
+        QStringList items = reply.split(',', QT_SKIP_EMPTY_PARTS);
 
         if (items.length() == 2)
         {
@@ -299,7 +299,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
 
     QString reply = QString::fromUtf8(SendMessageSynchronously(getImagesCommand.toUtf8()));
 
-    QStringList layers = reply.split('\n', QString::SkipEmptyParts);
+    QStringList layers = reply.split('\n', QT_SKIP_EMPTY_PARTS);
 
     const int layerCount = layers.length();
 
@@ -315,7 +315,7 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
 
     for (int i = 0; i < layerCount; ++i)
     {
-        QStringList layerData = layers[i].split(',', QString::SkipEmptyParts);
+        QStringList layerData = layers[i].split(',', QT_SKIP_EMPTY_PARTS);
         if (layerData.length() != 4)
         {
             return;
@@ -376,10 +376,9 @@ void gmic_qt_get_cropped_images(gmic_list<float> & images, gmic_list<char> & ima
     SendMessageSynchronously("command=gmic_qt_release_shared_memory");
 }
 
-void gmic_qt_output_images(gmic_list<float> & images, const gmic_list<char> & imageNames, GmicQt::OutputMode mode, const char * verboseLayersLabel)
+void gmic_qt_output_images(gmic_list<float> & images, const gmic_list<char> & imageNames, GmicQt::OutputMode mode)
 {
     unused(imageNames);
-    unused(verboseLayersLabel);
 
     if (images.size() > 0)
     {
@@ -391,142 +390,144 @@ void gmic_qt_output_images(gmic_list<float> & images, const gmic_list<char> & im
 
         QString outputImagesCommand = QString("command=gmic_qt_output_images\nmode=%1\n").arg(mode);
 
-        QString mappingName = QString("pdn_%1").arg(QUuid::createUuid().toString(QUuid::StringFormat::WithoutBraces));
+		for (size_t i = 0; i < images.size(); ++i)
+		{
+			QString mappingName = QString("pdn_%1").arg(QUuid::createUuid().toString(QUuid::StringFormat::WithoutBraces));
+
+			const cimg_library::CImg<float>& out = images[i];
+
+			const int width = out.width();
+			const int height = out.height();
+
+			const qint64 imageSizeInBytes = static_cast<qint64>(width) * static_cast<qint64>(height) * 4;
+
+			const DWORD capacityHigh = static_cast<DWORD>((imageSizeInBytes >> 32) & 0xFFFFFFFF);
+			const DWORD capacityLow = static_cast<DWORD>(imageSizeInBytes & 0x00000000FFFFFFFF);
+
+			ScopedFileMapping fileMappingObject(CreateFileMappingW(INVALID_HANDLE_VALUE,
+																   nullptr,
+																   PAGE_READWRITE,
+																   capacityHigh,
+																   capacityLow,
+																   reinterpret_cast<LPCWSTR>(mappingName.utf16())));
+			if (fileMappingObject)
+			{
+				ScopedFileMappingView mappedData(MapViewOfFile(fileMappingObject.get(), FILE_MAP_ALL_ACCESS, 0, 0, static_cast<size_t>(imageSizeInBytes)));
+
+				if (mappedData)
+				{
+					quint8* scan0 = static_cast<quint8*>(mappedData.get());
+					const int stride = width * 4;
+
+					if (out.spectrum() == 3)
+					{
+						const float* srcR = out.data(0, 0, 0, 0);
+						const float* srcG = out.data(0, 0, 0, 1);
+						const float* srcB = out.data(0, 0, 0, 2);
+
+						for (int y = 0; y < height; ++y)
+						{
+							quint8* dst = scan0 + (y * stride);
+
+							for (int x = 0; x < width; ++x)
+							{
+								dst[0] = Float2Uint8Clamped(*srcB++);
+								dst[1] = Float2Uint8Clamped(*srcG++);
+								dst[2] = Float2Uint8Clamped(*srcR++);
+								dst[3] = 255;
+
+								dst += 4;
+							}
+						}
+					}
+					else if (out.spectrum() == 4)
+					{
+						const float* srcR = out.data(0, 0, 0, 0);
+						const float* srcG = out.data(0, 0, 0, 1);
+						const float* srcB = out.data(0, 0, 0, 2);
+						const float* srcA = out.data(0, 0, 0, 3);
+
+						for (int y = 0; y < height; ++y)
+						{
+							quint8* dst = scan0 + (y * stride);
+
+							for (int x = 0; x < width; ++x)
+							{
+								dst[0] = Float2Uint8Clamped(*srcB++);
+								dst[1] = Float2Uint8Clamped(*srcG++);
+								dst[2] = Float2Uint8Clamped(*srcR++);
+								dst[3] = Float2Uint8Clamped(*srcA++);
+
+								dst += 4;
+							}
+						}
+					}
+					else if (out.spectrum() == 2)
+					{
+						const float* srcGray = out.data(0, 0, 0, 0);
+						const float* srcAlpha = out.data(0, 0, 0, 1);
+
+						for (int y = 0; y < height; ++y)
+						{
+							quint8* dst = scan0 + (y * stride);
+
+							for (int x = 0; x < width; ++x)
+							{
+								dst[0] = dst[1] = dst[2] = Float2Uint8Clamped(*srcGray++);
+								dst[3] = Float2Uint8Clamped(*srcAlpha++);
+
+								dst += 4;
+							}
+						}
+					}
+					else if (out.spectrum() == 1)
+					{
+						const float* srcGray = out.data(0, 0, 0, 0);
+
+						for (int y = 0; y < height; ++y)
+						{
+							quint8* dst = scan0 + (y * stride);
+
+							for (int x = 0; x < width; ++x)
+							{
+								dst[0] = dst[1] = dst[2] = Float2Uint8Clamped(*srcGray++);
+								dst[3] = 255;
+
+								dst += 4;
+							}
+						}
+					}
+					else
+					{
+						qWarning() << "The image must have between 1 and 4 channels. Actual value=" << out.spectrum();
+						return;
+					}
+
+					// Manually release the mapped data to ensue it is committed before the parent file mapping handle
+					// is moved into the host_paintdotnet::sharedMemory vector (which invalidates the previous handle).
+
+					mappedData.reset();
+
+					outputImagesCommand += "layer=" + mappingName + ","
+						+ QString::number(width) + ","
+						+ QString::number(height) + ","
+						+ QString::number(stride) + "\n";
 
 
-        const cimg_library::CImg<float>& out = images[0];
-
-        const int width = out.width();
-        const int height = out.height();
-
-        const qint64 imageSizeInBytes = static_cast<qint64>(width) * static_cast<qint64>(height) * 4;
-
-        const DWORD capacityHigh = static_cast<DWORD>((imageSizeInBytes >> 32) & 0xFFFFFFFF);
-        const DWORD capacityLow = static_cast<DWORD>(imageSizeInBytes & 0x00000000FFFFFFFF);
-
-        ScopedFileMapping fileMappingObject(CreateFileMappingW(INVALID_HANDLE_VALUE,
-                                                               nullptr,
-                                                               PAGE_READWRITE,
-                                                               capacityHigh,
-                                                               capacityLow,
-                                                               reinterpret_cast<LPCWSTR>(mappingName.utf16())));
-        if (fileMappingObject)
-        {
-            ScopedFileMappingView mappedData(MapViewOfFile(fileMappingObject.get(), FILE_MAP_ALL_ACCESS, 0, 0, static_cast<size_t>(imageSizeInBytes)));
-
-            if (mappedData)
-            {
-                quint8* scan0 = static_cast<quint8*>(mappedData.get());
-                const int stride = width * 4;
-
-                if (out.spectrum() == 3)
-                {
-                    const float* srcR = out.data(0, 0, 0, 0);
-                    const float* srcG = out.data(0, 0, 0, 1);
-                    const float* srcB = out.data(0, 0, 0, 2);
-
-                    for (int y = 0; y < height; ++y)
-                    {
-                        quint8* dst = scan0 + (y * stride);
-
-                        for (int x = 0; x < width; ++x)
-                        {
-                            dst[0] = Float2Uint8Clamped(*srcB++);
-                            dst[1] = Float2Uint8Clamped(*srcG++);
-                            dst[2] = Float2Uint8Clamped(*srcR++);
-                            dst[3] = 255;
-
-                            dst += 4;
-                        }
-                    }
-                }
-                else if (out.spectrum() == 4)
-                {
-                    const float* srcR = out.data(0, 0, 0, 0);
-                    const float* srcG = out.data(0, 0, 0, 1);
-                    const float* srcB = out.data(0, 0, 0, 2);
-                    const float* srcA = out.data(0, 0, 0, 3);
-
-                    for (int y = 0; y < height; ++y)
-                    {
-                        quint8* dst = scan0 + (y * stride);
-
-                        for (int x = 0; x < width; ++x)
-                        {
-                            dst[0] = Float2Uint8Clamped(*srcB++);
-                            dst[1] = Float2Uint8Clamped(*srcG++);
-                            dst[2] = Float2Uint8Clamped(*srcR++);
-                            dst[3] = Float2Uint8Clamped(*srcA++);
-
-                            dst += 4;
-                        }
-                    }
-                }
-                else if (out.spectrum() == 2)
-                {
-                    const float* srcGray = out.data(0, 0, 0, 0);
-                    const float* srcAlpha = out.data(0, 0, 0, 1);
-
-                    for (int y = 0; y < height; ++y)
-                    {
-                        quint8* dst = scan0 + (y * stride);
-
-                        for (int x = 0; x < width; ++x)
-                        {
-                            dst[0] = dst[1] = dst[2] = Float2Uint8Clamped(*srcGray++);
-                            dst[3] = Float2Uint8Clamped(*srcAlpha++);
-
-                            dst += 4;
-                        }
-                    }
-                }
-                else if (out.spectrum() == 1)
-                {
-                    const float* srcGray = out.data(0, 0, 0, 0);
-
-                    for (int y = 0; y < height; ++y)
-                    {
-                        quint8* dst = scan0 + (y * stride);
-
-                        for (int x = 0; x < width; ++x)
-                        {
-                            dst[0] = dst[1] = dst[2] = Float2Uint8Clamped(*srcGray++);
-                            dst[3] = 255;
-
-                            dst += 4;
-                        }
-                    }
-                }
-                else
-                {
-                    qWarning() << "The image must have between 1 and 4 channels. Actual value=" << out.spectrum();
-                    return;
-                }
-
-                // Manually release the mapped data to ensue it is committed before the parent file mapping handle
-                // is moved into the host_paintdotnet::sharedMemory vector (which invalidates the previous handle).
-
-                mappedData.reset();
-
-                outputImagesCommand += "layer=" + mappingName + ","
-                    + QString::number(width) + ","
-                    + QString::number(height) + ","
-                    + QString::number(stride) + "\n";
-
-
-                host_paintdotnet::sharedMemory.push_back(std::move(fileMappingObject));
-            }
-            else
-            {
-                qWarning() << "MapViewOfFile failed GetLastError=" << GetLastError();
-                return;
-            }
-        }
-        else
-        {
-            qWarning() << "CreateFileMappingW failed GetLastError=" << GetLastError();
-            return;
-        }
+					host_paintdotnet::sharedMemory.push_back(std::move(fileMappingObject));
+				}
+				else
+				{
+					qWarning() << "MapViewOfFile failed GetLastError=" << GetLastError();
+					return;
+				}
+			}
+			else
+			{
+				qWarning() << "CreateFileMappingW failed GetLastError=" << GetLastError();
+				return;
+			}
+		}
 
         SendMessageSynchronously(outputImagesCommand.toUtf8());
     }
@@ -594,7 +595,7 @@ int main(int argc, char *argv[])
     disableOutputMode(GmicQt::NewImage);
     disableOutputMode(GmicQt::NewLayers);
     disableOutputMode(GmicQt::NewActiveLayers);
-	
+
 	// disablePreviewMode(GmicQt::FirstOutput);
     disablePreviewMode(GmicQt::SecondOutput);
     disablePreviewMode(GmicQt::ThirdOutput);
