@@ -24,8 +24,11 @@
  */
 
 #include "Utils.h"
+#include <QDebug>
 #include <QFileInfo>
+#include <QRegExp>
 #include <QString>
+#include "Common.h"
 #include "Host/host.h"
 #include "gmic.h"
 
@@ -110,17 +113,70 @@ const QString & pluginCodeName()
 
 const char * commandFromOutputMessageMode(OutputMessageMode mode)
 {
-  static const char commands[][6] = {"v -", "v -99", "v 0", "debug"};
-  if (mode == GmicQt::Quiet) {
-    return commands[0];
-  } else if (mode >= GmicQt::VerboseLayerName && mode <= GmicQt::VerboseLogFile) {
-    return commands[1];
-  } else if (mode == GmicQt::VeryVerboseConsole || mode == GmicQt::VeryVerboseLogFile) {
-    return commands[2];
-  } else if (mode == GmicQt::DebugConsole || mode == GmicQt::DebugLogFile) {
-    return commands[3];
+  switch (mode) {
+  case Quiet:
+  case VerboseConsole:
+  case VerboseLogFile:
+  case UnspecifiedOutputMessageMode:
+    return "";
+  case VeryVerboseConsole:
+  case VeryVerboseLogFile:
+    return "v 3";
+  case DebugConsole:
+  case DebugLogFile:
+    return "debug";
   }
-  return commands[0];
+  return "";
+}
+
+void downcaseCommandTitle(QString & title)
+{
+  QMap<int, QString> acronyms;
+  // Acronyms
+  QRegExp re("([A-Z0-9]{2,255})");
+  int index = 0;
+  while ((index = re.indexIn(title, index)) != -1) {
+    QString pattern = re.cap(0);
+    acronyms[index] = pattern;
+    index += pattern.length();
+  }
+
+  // 3D
+  re.setPattern("([1-9])[dD] ");
+  if ((index = re.indexIn(title, 0)) != -1) {
+    acronyms[index] = re.cap(1) + "d ";
+  }
+
+  // B&amp;W
+  re.setPattern("(B&amp;W|[ \\[]Lab|[ \\[]YCbCr)");
+  index = 0;
+  while ((index = re.indexIn(title, index)) != -1) {
+    acronyms[index] = re.cap(1);
+    index += re.cap(1).length();
+  }
+
+  // Uppercase letter in last position, after a space
+  re.setPattern(" ([A-Z])$");
+  if ((index = re.indexIn(title, 0)) != -1) {
+    acronyms[index] = re.cap(0);
+  }
+  title = title.toLower();
+  QMap<int, QString>::const_iterator it = acronyms.cbegin();
+  while (it != acronyms.cend()) {
+    title.replace(it.key(), it.value().length(), it.value());
+    ++it;
+  }
+  title[0] = title[0].toUpper();
+}
+
+void appendWithSpace(QString & str, const QString & other)
+{
+  if (str.isEmpty() || other.isEmpty()) {
+    str += other;
+    return;
+  }
+  str += QChar(' ');
+  str += other;
 }
 
 } // namespace GmicQt
