@@ -43,8 +43,8 @@
  * The fact that you are presently reading this means that you have had
  * knowledge of the CeCILL license and that you accept its terms.
  */
-#ifndef _ABSTRACTPARAMETER_H_
-#define _ABSTRACTPARAMETER_H_
+#ifndef ZART_ABSTRACTPARAMETER_H
+#define ZART_ABSTRACTPARAMETER_H
 
 #include <QDomNode>
 #include <QObject>
@@ -54,8 +54,8 @@ class KeypointList;
 class AbstractParameter : public QObject {
   Q_OBJECT
 public:
-  AbstractParameter(QObject * parent = 0);
-  virtual ~AbstractParameter();
+  AbstractParameter(QObject * parent = nullptr);
+  virtual ~AbstractParameter() override;
   virtual bool isVisible() const;
   virtual void addTo(QWidget *, int row) = 0;
   virtual QString textValue() const = 0;
@@ -66,9 +66,9 @@ public:
   virtual void addToKeypointList(KeypointList &) const;
   virtual void extractPositionFromKeypointList(KeypointList &);
 
-  static AbstractParameter * createFromNode(QDomNode node, QObject * parent = 0);
+  static AbstractParameter * createFromNode(QDomNode node, QObject * parent = nullptr);
 signals:
   void valueChanged();
 };
 
-#endif // _ABSTRACTPARAMETER_H_
+#endif // ZART_ABSTRACTPARAMETER_H
